@@ -46,6 +46,7 @@
    noticing memory leaks quickly. */
 
 /* #define DEBUG_MEMORY_LEAKAGE */
+/* #define DEBUG_MEMORY_LEAKAGE_ON_EXIT */
 
 /* Define this if you want exhaustive (and very slow) checking of the
    malloc pool for corruption. */
@@ -81,20 +82,36 @@
 
 /* #define DEBUG_FAILOVER_MESSAGES */
 
+/* Define this to include contact messages in failover message debugging.
+   The contact messages are sent once per second, so this can generate a
+   lot of log entries. */
+
+/* #define DEBUG_FAILOVER_CONTACT_MESSAGES */
+
 /* Define this if you want debugging output for DHCP failover protocol
-   lease assignment timing. */
+   event timeout timing. */
 
 /* #define DEBUG_FAILOVER_TIMING */
 
+/* Define this if you want to include contact message timing, which is
+   performed once per second and can generate a lot of log entries. */
+
+/* #define DEBUG_FAILOVER_CONTACT_TIMING */
+
 /* Define this if you want all leases written to the lease file, even if
    they are free leases that have never been used. */
 
 /* #define DEBUG_DUMP_ALL_LEASES */
 
+/* Define this if you want to see the requests and replies between the
+   DHCP code and the DNS library code. */
+
+/* #define DEBUG_DNS_UPDATES */
+
 /* Define this if you want DHCP failover protocol support in the DHCP
    server. */
 
-#define FAILOVER_PROTOCOL
+/* #define FAILOVER_PROTOCOL */
 
 /* Define this if you want DNS update functionality to be available. */
 
@@ -121,7 +138,7 @@
    you don't choose, one will be chosen for you in your system's config
    header.    DON'T MESS WITH THIS UNLESS YOU KNOW WHAT YOU'RE DOING!!! */
 
-/* Define this to use the standard BSD socket API.
+/* Define USE_SOCKETS to use the standard BSD socket API.
 
    On many systems, the BSD socket API does not provide the ability to
    send packets to the 255.255.255.255 broadcast address, which can
@@ -167,6 +184,12 @@
 
 /* #define DHCPD_LOG_FACILITY LOG_DAEMON */
 
+
+/* Define this if you want to be able to execute external commands
+   during conditional evaluation. */
+
+/* #define ENABLE_EXECUTE */
+
 /* Define this if you aren't debugging and you want to save memory
    (potentially a _lot_ of memory) by allocating leases in chunks rather
    than one at a time. */
@@ -176,4 +199,31 @@
 /* Define this if you want to be able to save and playback server operational
    traces. */
 
-#define TRACING
+/* #define TRACING */
+
+/* Define this if you want the server to use the previous behavior
+   when determining the DDNS TTL.  If the user has specified a ddns-ttl
+   option that is used to detemine the ttl.  (If the user specifies
+   an option that references the lease structure it is only usable
+   for v4.  In that case v6 will use the default.) Otherwise when
+   defined the defaults are: v4 - 1/2 the lease time,
+   v6 - DEFAULT_DDNS_TTL.  When undefined the defaults are 1/2 the
+   (preferred) lease time for both but with a cap on the maximum. */
+
+/* #define USE_OLD_DDNS_TTL */
+
+/* Define this if you want a DHCPv6 server to send replies to the
+   source port of the message it received.  This is useful for testing
+   but is only included for backwards compatibility. */
+/* #define REPLY_TO_SOURCE_PORT */
+
+/* Define this if you want to enable strict checks in DNS Updates mechanism.
+   Do not enable this unless are DHCP developer. */
+/* #define DNS_UPDATES_MEMORY_CHECKS */
+
+/* Define this if you want to allow domain list in domain-name option.
+   RFC2132 does not allow that behavior, but it is somewhat used due
+   to historic reasons. Note that it may be removed some time in the
+   future. */
+
+#define ACCEPT_LIST_IN_DOMAIN_NAME
